Task: https://github.com/AutoRepoReviewITPD/AutoRepoReview/issues/12

Number of TDD cycles: 1

Failing test:
    1. Commit: https://github.com/AutoRepoReviewITPD/AutoRepoReview/pull/31/commits/f42963606beb4c4ce4642141cee7d684aa4b15a0
    2. Workflow: https://github.com/AutoRepoReviewITPD/AutoRepoReview/actions/runs/19595663333/job/56119943307
Passing test:
    1. Commit: https://github.com/AutoRepoReviewITPD/AutoRepoReview/pull/31
    2. Workflow: https://github.com/AutoRepoReviewITPD/AutoRepoReview/actions/runs/19595686095/job/56119995187
Refactor:
    1. Commit: https://github.com/AutoRepoReviewITPD/AutoRepoReview/pull/31/commits/a48c3ea40ffda088997244a92d7d38bd94a09469
    2. Workflow: https://github.com/AutoRepoReviewITPD/AutoRepoReview/actions/runs/19596068619/job/56120865784

Comparing TDD with previous development approach:

(Ilnar)
I used TDD long before this assignment. This methodogy allows me to think about good implementation and architecture not after the code is written, but before that. Moreover, it mitigates the risk of system being not tested.
